package com.jcg;


import javax.naming.Context;
import org.apache.camel.EndpointInject;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.dataset.SimpleDataSet;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.Test;

public class WeightedRoundRobinLoadBalance extends CamelTestSupport{
	
	@EndpointInject(uri="mock:m1")
	MockEndpoint m1;
	@EndpointInject(uri="mock:m2")
	MockEndpoint m2;
	@EndpointInject(uri="mock:end")
	MockEndpoint end;
	
	@Override
	protected RouteBuilder createRouteBuilder() throws Exception{
		return new RouteBuilder(){
			@Override
			public void configure() throws Exception {
				// first argument of weighted method is a boolean defines if the policy is
				// Round robin (true) or Random (false)
				from("dataset:start").loadBalance().weighted(true,"2,1").to(m1,m2).end().to(end);
			}
		};
	}
	
	@Override
	protected Context createJndiContext() throws Exception{
		SimpleDataSet sds = new SimpleDataSet();
		sds.setSize(6);
		Context context = super.createJndiContext();
		context.bind("start", sds);
		return context;
	}
	
	@Test
	public void testSending() throws Exception{
		m1.expectedMessageCount(4);
		m2.expectedMessageCount(2);
		end.expectedMessageCount(6);
		template.sendBody("dataset:start", "");
		m1.assertIsSatisfied();
		m2.assertIsSatisfied();
		end.assertIsSatisfied();
	}
}
